{% extends "base.html" %}
{% load i18n thumbnail %}
{% block title %}{% trans "Update image" %}{% endblock %}

{% block main %}
    <h1>{% trans "Add additional information to your image" %}</h1>
    <div class="row">
        <div class="col-md-4">
            <img src="{% thumbnail image.image 300x300 upscale %}" alt="Image" style="max-width: 100%; height: auto;" />
        </div>
        <div class="col-md-8">
            {% include "media_library/partials/mediaitem_form.html" with button_text="Save image" %}
        </div>
    </div>
{% endblock %}

{% block extrascript %}
    <script>
        $(document).ready(function(){
            var tagsource = {{ tags|safe }};
            $("[data-class=multilingual-tags-field]").tagging(tagsource);
        });
    </script>
{% endblock %}
