.embed-container {
    position: relative;
    padding-bottom: 56.25%;
    height: 0;
    overflow: hidden;
    max-width: 100%;
    height: auto;
}
.embed-container iframe,
.embed-container object,
.embed-container embed {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
}

img {
    max-width: 100%;
}

.mediaItemWrapper {
    .mediaImageWrapper {
        width: 100%;
        text-align: center;
    }
    position: relative;
    height: 240px;
    margin-bottom: 20px;
}

.pointer {
    cursor: pointer;
}

.positionHandle {
    border: 1px solid #cccccc;
    border-radius: 3px;
    text-align: center;
    width: 30px;
    height: 20px;
    position: relative;
    padding: 2px;
    .handlebar {
        display: block;
        background-color: #cccccc;
        height: 3px;
        margin-bottom: 2px;
        width: 100%;
        border-radius: 2px;
    }
}

.userMediaImageUploaded {
    border: none;
}

.video {
    display: block;
    position: relative;
    img, span {
        position: absolute;
    }
    color: #777;
    .glyphicon {
        font-size: 32px;
        margin: 4px;
    }
}

.video:hover {
    color: #eee;
}

.viewerbg {
    background: rgba(0, 0, 0, 0.5);
    width:      100%;
    height:     100%;
    z-index:    100;
    top:        0;
    left:       0;
    position:   fixed;
    text-align: center;
}
